@@ -89,7 +89,6 @@ pub fn all(lint_params: LintParams) -> Vec<Box<dyn Rule>> {
 
         rules.extend(prefer_regex_literals::prefer_regex_literals(
             program,
-            &source_map,
             &lint_config.prefer_regex_literals,
             top_level_ctxt,
             es_version,
@@ -119,12 +118,7 @@ pub fn all(lint_params: LintParams) -> Vec<Box<dyn Rule>> {
             &lint_config.no_restricted_syntax,
         ));
 
-        rules.extend(radix::radix(
-            program,
-            &source_map,
-            top_level_ctxt,
-            &lint_config.radix,
-        ));
+        rules.extend(radix::radix(program, top_level_ctxt, &lint_config.radix));
 
         rules.extend(no_bitwise::no_bitwise(&lint_config.no_bitwise));
 
